@@ -98,49 +98,64 @@ echo "  $VRT/cream/help"
 mkdir -p $VRT/cream/help
 echo "  $VRT/cream/lang"
 mkdir -p $VRT/cream/lang
-echo "  $VRT/cream/spelldicts"
-mkdir -p $VRT/cream/spelldicts
+#echo "  $VRT/cream/spelldicts"
+#mkdir -p $VRT/cream/spelldicts
 
 # copy runtime files
 echo "Copying runtime files..."
 echo "  $VRT/cream/creamrc"
-cp -uvf $HERE/creamrc $VRT/cream/
+#cp -uvf $HERE/creamrc $VRT/cream/
+install -p -m 644 $HERE/creamrc $VRT/cream/
 echo "  $VRT/cream/*.vim"
-cp -uvf $HERE/*.vim $VRT/cream/
-#echo "  $VRT/cream/cream.png"
-#cp -uvf $HERE/cream.png $VRT/cream/
-#echo "  $VRT/cream/cream.svg"
-#cp -uvf $HERE/cream.svg $VRT/cream/
-#echo "  $VRT/cream/cream.ico"
-#cp -uvf $HERE/cream.ico $VRT/cream/
+#cp -uvf $HERE/*.vim $VRT/cream/
+install -p -m 644 $HERE/*.vim $VRT/cream/
+###echo "  $VRT/cream/cream.png"
+###cp -uvf $HERE/cream.png $VRT/cream/
+###echo "  $VRT/cream/cream.svg"
+###cp -uvf $HERE/cream.svg $VRT/cream/
+###echo "  $VRT/cream/cream.ico"
+###cp -uvf $HERE/cream.ico $VRT/cream/
 echo "  $VRT/cream/addons/*.vim"
-cp -uvf $HERE/addons/*.vim $VRT/cream/addons/
+#cp -uvf $HERE/addons/*.vim $VRT/cream/addons/
+install -p -m 644 $HERE/addons/*.vim $VRT/cream/addons/
 echo "  $VRT/cream/bitmaps/*.xpm"
-cp -uvf $HERE/bitmaps/*.xpm $VRT/cream/bitmaps/
-#echo "  $VRT/cream/bitmaps/*.bmp"
-#cp -uvf $HERE/bitmaps/*.bmp $VRT/cream/bitmaps/
+#cp -uvf $HERE/bitmaps/*.xpm $VRT/cream/bitmaps/
+install -p -m 644 $HERE/bitmaps/*.xpm $VRT/cream/bitmaps/
+###echo "  $VRT/cream/bitmaps/*.bmp"
+###cp -uvf $HERE/bitmaps/*.bmp $VRT/cream/bitmaps/
 echo "  $VRT/cream/docs/*.txt"
-cp -uvf $HERE/docs/*.txt $VRT/cream/docs/
+#cp -uvf $HERE/docs/*.txt $VRT/cream/docs/
+install -p -m 644 $HERE/docs/*.txt $VRT/cream/docs/
 echo "  $VRT/cream/docs-html/*.html"
-cp -uvf $HERE/docs-html/*.html $VRT/cream/docs-html/
+#cp -uvf $HERE/docs-html/*.html $VRT/cream/docs-html/
+install -p -m 644 $HERE/docs-html/*.html $VRT/cream/docs-html/
 echo "  $VRT/cream/docs-html/css.php"
-cp -uvf $HERE/docs-html/css.php $VRT/cream/docs-html/
+#cp -uvf $HERE/docs-html/css.php $VRT/cream/docs-html/
+install -p -m 644 $HERE/docs-html/css.php $VRT/cream/docs-html/
 echo "  $VRT/cream/docs-html/favicon.ico"
-cp -uvf $HERE/docs-html/favicon.ico $VRT/cream/docs-html/
+#cp -uvf $HERE/docs-html/favicon.ico $VRT/cream/docs-html/
+install -p -m 644 $HERE/docs-html/favicon.ico $VRT/cream/docs-html/
 echo "  $VRT/cream/docs-html/*.png"
-cp -uvf $HERE/docs-html/*.png $VRT/cream/docs-html/
+#cp -uvf $HERE/docs-html/*.png $VRT/cream/docs-html/
+install -p -m 644 $HERE/docs-html/*.png $VRT/cream/docs-html/
 echo "  $VRT/cream/docs-html/*.gif"
-cp -uvf $HERE/docs-html/*.gif $VRT/cream/docs-html/
+#cp -uvf $HERE/docs-html/*.gif $VRT/cream/docs-html/
+install -p -m 644 $HERE/docs-html/*.gif $VRT/cream/docs-html/
 echo "  $VRT/cream/filetypes/*.vim"
-cp -uvf $HERE/filetypes/*.vim $VRT/cream/filetypes/
+#cp -uvf $HERE/filetypes/*.vim $VRT/cream/filetypes/
+install -p -m 644 $HERE/filetypes/*.vim $VRT/cream/filetypes/
 echo "  $VRT/cream/help/*.txt"
-cp -uvf $HERE/help/*.txt $VRT/cream/help/
+#cp -uvf $HERE/help/*.txt $VRT/cream/help/
+install -p -m 644 $HERE/help/*.txt $VRT/cream/help/
 echo "  $VRT/cream/lang/*.vim"
-cp -uvf $HERE/lang/*.vim $VRT/cream/lang/
-echo "  $VRT/cream/spelldicts/cream-spell-dict-eng-s*.vim"
-cp -uvf $HERE/spelldicts/cream-spell-dict-eng-s*.vim $VRT/cream/spelldicts/
-echo "  $VRT/cream/spelldicts/cream-spell-dict.vim"
-cp -uvf $HERE/spelldicts/cream-spell-dict.vim $VRT/cream/spelldicts/
+#cp -uvf $HERE/lang/*.vim $VRT/cream/lang/
+###install -p -m 644 $HERE/lang/*.vim $VRT/cream/lang/
+###echo "  $VRT/cream/spelldicts/cream-spell-dict-eng-s*.vim"
+#cp -uvf $HERE/spelldicts/cream-spell-dict-eng-s*.vim $VRT/cream/spelldicts/
+###install -p -m 644 $HERE/spelldicts/cream-spell-dict-eng-s*.vim $VRT/cream/spelldicts/
+###echo "  $VRT/cream/spelldicts/cream-spell-dict.vim"
+####cp -uvf $HERE/spelldicts/cream-spell-dict.vim $VRT/cream/spelldicts/
+###install -p -m 644 $HERE/spelldicts/cream-spell-dict.vim $VRT/cream/spelldicts/
 
 
 # other system files
@@ -149,25 +164,36 @@ cp -uvf $HERE/spelldicts/cream-spell-dict.vim $VRT/cream/spelldicts/
 echo "Copying shell command..."
 echo "  $PREFIX/bin/cream"
 mkdir -p $PREFIX/bin
-cp -uvf $HERE/cream $PREFIX/bin/
+#cp -uvf $HERE/cream $PREFIX/bin/
+install -p -m 755 $HERE/cream $PREFIX/bin/
 
 # copy menu entry
 echo "Copying GNOME menu entry..."
 echo "  $PREFIX/share/applications/cream.desktop"
 mkdir -p $PREFIX/share/applications
-cp -uvf $HERE/cream.desktop $PREFIX/share/applications/
+#cp -uvf $HERE/cream.desktop $PREFIX/share/applications/
+install -p -m 755 $HERE/cream.desktop $PREFIX/share/applications/
 
 # copy icons
 echo "Copying graphic icons..."
 echo "  $PREFIX/share/icons"
 mkdir -p $PREFIX/share/icons
-cp -uvf $HERE/cream.svg $PREFIX/share/icons/
-cp -uvf $HERE/cream.png $PREFIX/share/icons/
-
+#cp -uvf $HERE/cream.svg $PREFIX/share/icons/
+install -p -m 644 $HERE/cream.svg $PREFIX/share/icons/
+#cp -uvf $HERE/cream.png $PREFIX/share/icons/
+install -p -m 644 $HERE/cream.png $PREFIX/share/icons/
 
 # cleanup old installations
 echo "Cleaning up previous versions..."
 
+# 0.38
+if [ -d "$VRT/cream/spelldicts" ]; then
+	rm -f $VRT/cream/spelldicts/*
+	rmdir $VRT/cream/spelldicts
+fi
+if [ -e "$VRT/cream/help/opsplorer.txt" ]; then
+	rm -f $VRT/cream/help/opsplorer.txt
+fi
 # 0.37
 if [ -e "$VRT/cream/cream-explorer.vim" ]; then
 	rm -f $VRT/cream/cream-explorer.vim
